@@ -17,9 +17,9 @@ use URI::Escape;
 use Plack::Request;
 use Plack::Response;
 use Web::Solid::Auth::Listener;
-use Web::Solid::Util;
+use Web::Solid::Auth::Util;
 
-our $VERSION = "0.4";
+our $VERSION = "0.5";
 
 has webid => (
     is => 'ro' ,
@@ -50,8 +50,7 @@ has client_id => (
 );
 
 sub _build_agent {
-    my $ua     = new LWP::UserAgent;
-    my $agent  = "Web::Solid::Auth/$VERSION " . $ua->agent;
+    my $ua = WP::UserAgent->new(agent => "Web::Solid::Auth/$VERSION");
     $ua;
 }
 
@@ -279,7 +278,7 @@ sub get_webid_openid_provider {
 
     return undef unless $res;
 
-    my $util  = Web::Solid::Util->new;
+    my $util  = Web::Solid::Auth::Util->new;
     my $model = $util->parse_turtle($res);
 
     my $sparql =<<EOF;
